outputs property
List<CameraOutput>
get
outputs
The ouptuts frame data is streamed to from device.
Implementation
List<CameraOutput> get outputs;
The ouptuts frame data is streamed to from device.
List<CameraOutput> get outputs;