FocusMode enum
Indicates the mode of the focus on the receiver's device, if it has one.
See: CameraController.supportedFocusModes. CameraController.setFocusMode.
Values
- fixed → const FocusMode
-
Focus is fixed.
The camera is always in this mode if the focus is not adjustable. If the camera has auto-focus, this mode can fix the focus, which is usually at hyperfocal distance.
- continuousImageAutoFocus → const FocusMode
-
Continuous auto focus mode intended for taking pictures.
The camera continuously tries to focus. The speed of focus change is more aggressive than continuousVideoAutoFocus. Auto focus starts when the parameter is set.
Not all platforms will support different auto focus modes for images and videos and will default to a more general auto focus mode.
- continuousVideoAutoFocus → const FocusMode
-
Continuous auto focus mode intended for taking pictures.
The camera continuously tries to focus. This is the best choice for video recording because the focus changes smoothly. Applications still can call ImageCaptureOutput.takePicture in this mode but the subject may not be in focus.
Not all platforms will support different auto focus modes for images and videos and will default to a more general auto focus mode.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited