OutputRotation enum
Degrees to rotate the output image for a CameraOutput.
Values
- rotation0 → const OutputRotation
-
Rotate the output 0 degrees counter-clockwise from its natural orientation.
For example, a phone's natural orientation is typically portrait-up.
- rotation90 → const OutputRotation
-
Rotate the output 90 degrees counter-clockwise from its natural orientation.
For example, a phone's natural orientation is typically portrait-up.
- rotation180 → const OutputRotation
-
Rotate the output 180 degrees counter-clockwise from its natural orientation.
For example, a phone's natural orientation is typically portrait-up.
- rotation270 → const OutputRotation
-
Rotate the output 270 degrees counter-clockwise from its natural orientation.
For example, a phone's natural orientation is typically portrait-up.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
OutputRotation> - A constant List of the values in this enum, in order of their declaration.